﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Linq;
using System.Text;
using System.Threading;
using System.Windows.Forms;
using Arction.LightningChartUltimate;
using Arction.LightningChartUltimate.Axes;
using Arction.LightningChartUltimate.ChartManager;
using Arction.LightningChartUltimate.SeriesXY;
using Arction.LightningChartUltimate.Views.ViewXY;

namespace YAxesControl
{
    public partial class Form1 : Form
    {
        LightningChartUltimate chart;
        ChartManager cm = new ChartManager();

        public Form1()
        {
            InitializeComponent();
            InitChart(this);
        }

        private void InitChart(Control parent)
        {
            chart = new LightningChartUltimate();
            chart.ChartManager = cm;
            
            chart.Parent = parent;

            chart.Dock = DockStyle.Fill;

            chart.BeginUpdate();

            //차트 배경
            chart.Background.Color = Color.Transparent;
            chart.Background.GradientColor = Color.Transparent;
            chart.Background.Style = RectFillStyle.None;

            chart.Title.Visible = false;
            chart.RenderOptions.AntiAliasLevel = 0; // Disable hw anti-aliasing.
            chart.ThrowChartExceptions = true;

            ViewXY chartView = chart.ViewXY;

            chartView.AxisLayout.YAxesLayout = YAxesLayout.Stacked;

            chartView.GraphBorderColor = Color.Black;
            chartView.GraphBackground.Color = Color.Transparent;
            chartView.GraphBackground.GradientColor = Color.Transparent;
            chartView.GraphBackground.Style = RectFillStyle.None;

            chartView.LegendBox.Position = LegendBoxPosition.TopLeft;
            chartView.LegendBox.Visible = false;
            chartView.DropOldSeriesData = true;


            chartView.AxisLayout.AutoAdjustMargins = false;
            chartView.AxisLayout.YAxisTitleAutoPlacement = false;
            chartView.AxisLayout.YAxisAutoPlacement = YAxisAutoPlacement.Off;
            chartView.AxisLayout.YAxesLayout = YAxesLayout.Stacked;

            chartView.AxisLayout.XAxisAutoPlacement = XAxisAutoPlacement.AllBottom;
            chartView.AxisLayout.XAxisTitleAutoPlacement = false;


            chartView.YAxes.Clear();

            for (int i = 0; i < 5; i++)
            {
                AddYAxesAndSeries();
            }

            chart.EndUpdate();
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            AddYAxesAndSeries();
        }

        private void AddYAxesAndSeries()
        {
            int index = AddYAxes();
            AddSeries(index);
        }

        private int AddYAxes()
        {
            this.chart.BeginUpdate();

            ViewXY chartView = chart.ViewXY;

            AxisY yAxis = new AxisY(chartView);
            yAxis.MajorGrid.Visible = false;
            yAxis.Title.Color = yAxis.AxisColor;
            yAxis.ValueType = AxisValueType.Number;

            yAxis.Title.Visible = false;
            yAxis.LabelsColor = Color.Black;
            yAxis.AxisColor = Color.Black;
            yAxis.AxisThickness = 1;
            yAxis.MajorDivTickStyle.Color = Color.Black;
            yAxis.MinorDivTickStyle.Color = Color.Black;

            chartView.YAxes.Add(yAxis);

            this.chart.EndUpdate();

            return chartView.YAxes.Count - 1;
        }

        private void AddSeries(int index)
        {
            this.chart.BeginUpdate();
            ViewXY chartView = this.chart.ViewXY;

            //Y축의 맨마지막 지정
            SampleDataSeries series = new SampleDataSeries(chartView, chartView.XAxes[0], chartView.YAxes[index]);
            series.LineStyle.Width = 1;
            series.LineStyle.AntiAliasing = LineAntialias.None;
            series.SampleFormat = SampleFormat.SingleFloat;
            series.SamplingFrequency = double.NaN;
            //성능향상
            series.PointsOptimization = PointsRenderOptimization.Pixels;

            //스크롤시 안깨지게
            series.ScrollingStabilizing = true;
            series.ScrollModePointsKeepLevel = 1;

            series.MouseInteraction = false;
            chartView.SampleDataSeries.Add(series);
            this.chart.EndUpdate();
        }

        

        private void btnRemove_Click(object sender, EventArgs e)
        {
            this.chart.BeginUpdate();

            ViewXY viewXY = this.chart.ViewXY;
            if (viewXY.YAxes.Count != 0)
            {
                viewXY.SampleDataSeries.RemoveAt(0);
                viewXY.YAxes.RemoveAt(0);
            }

            this.chart.EndUpdate();
        }
    }
}
